==> haskell-split-0.2.5-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-split.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 split
version:              0.2.5
visibility:           public
id:                   split-0.2.5-KSNJtK4iVn96dAw1dg6ivl
key:                  split-0.2.5-KSNJtK4iVn96dAw1dg6ivl
license:              BSD-3-Clause
copyright:            (c) Brent Yorgey, Louis Wasserman 2008-2012
maintainer:           byorgey@gmail.com
author:               Brent Yorgey
stability:            stable
synopsis:             Combinator library for splitting lists.
description:
    A collection of various methods for splitting
    lists into parts, akin to the \"split\" function
    found in several mainstream languages. Here is
    its tale:

    Once upon a time the standard "Data.List" module
    held no function for splitting a list into parts
    according to a delimiter.  Many a brave
    lambda-knight strove to add such a function, but
    their striving was in vain, for Lo, the Supreme
    Council fell to bickering amongst themselves what
    was to be the essential nature of the One True
    Function which could cleave a list in twain (or
    thrain, or any required number of parts).

    And thus came to pass the split package,
    comprising divers functions for splitting a list
    asunder, each according to its nature.  And the
    Supreme Council had no longer any grounds for
    argument, for the favored method of each was
    contained therein.

    To get started, see the "Data.List.Split" module.

category:             List
abi:                  1ce8f6c68ff97e06f0f20fb07ac7c3f1
exposed:              True
exposed-modules:      Data.List.Split Data.List.Split.Internals
import-dirs:          /usr/lib/ghc-9.4.8/site-local/split-0.2.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/split-0.2.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/split-0.2.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-split
hs-libraries:         HSsplit-0.2.5-KSNJtK4iVn96dAw1dg6ivl
depends:              base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-split/html/split.haddock
haddock-html:         /usr/share/doc/haskell-split/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-split-0.2.5-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-split.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 split
version:              0.2.5
visibility:           public
id:                   split-0.2.5-1cvcRB3t1btB7X53ioPSfn
key:                  split-0.2.5-1cvcRB3t1btB7X53ioPSfn
license:              BSD-3-Clause
copyright:            (c) Brent Yorgey, Louis Wasserman 2008-2012
maintainer:           byorgey@gmail.com
author:               Brent Yorgey
stability:            stable
synopsis:             Combinator library for splitting lists.
description:
    A collection of various methods for splitting
    lists into parts, akin to the \"split\" function
    found in several mainstream languages. Here is
    its tale:

    Once upon a time the standard "Data.List" module
    held no function for splitting a list into parts
    according to a delimiter.  Many a brave
    lambda-knight strove to add such a function, but
    their striving was in vain, for Lo, the Supreme
    Council fell to bickering amongst themselves what
    was to be the essential nature of the One True
    Function which could cleave a list in twain (or
    thrain, or any required number of parts).

    And thus came to pass the split package,
    comprising divers functions for splitting a list
    asunder, each according to its nature.  And the
    Supreme Council had no longer any grounds for
    argument, for the favored method of each was
    contained therein.

    To get started, see the "Data.List.Split" module.

category:             List
abi:                  99a4385c2213e9df685fb4a56e8d837c
exposed:              True
exposed-modules:      Data.List.Split Data.List.Split.Internals
import-dirs:          /usr/lib/ghc-9.4.8/site-local/split-0.2.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/split-0.2.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/split-0.2.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-split
hs-libraries:         HSsplit-0.2.5-1cvcRB3t1btB7X53ioPSfn
depends:              base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-split/html/split.haddock
haddock-html:         /usr/share/doc/haskell-split/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
